//Uses Rocket Launcher datablocks
%errorC = ForceRequiredAddOn("Weapon_Rocket_Launcher");
if(%errorC == $Error::AddOn_Disabled)
{
	RocketLauncherItem.uiName = "";
	RocketLauncherProjectile.uiName = "";
}

//audio
datablock AudioProfile(RobloxRocketFireSound)
{
	filename    = "./fire.wav";
	description = AudioClose3d;
	preload = true;
};
datablock ProjectileData(RobloxRocketLauncherProjectile)
{
	projectileShapeName = "Add-Ons/Weapon_Rocket_Launcher/RocketProjectile.dts";
	directDamage        = 30;
	directDamageType = $DamageType::RocketDirect;
	radiusDamageType = $DamageType::RocketRadius;
	impactImpulse	   = 1000;
	verticalImpulse	   = 1000;
	explosion           = rocketExplosion;
	particleEmitter     = rocketTrailEmitter;

	brickExplosionRadius = 3;
	brickExplosionImpact = false;          //destroy a brick if we hit it directly?
	brickExplosionForce  = 30;             
	brickExplosionMaxVolume = 30;          //max volume of bricks that we can destroy
	brickExplosionMaxVolumeFloating = 60;  //max volume of bricks that we can destroy if they aren't connected to the ground (should always be >= brickExplosionMaxVolume)

	sound = rocketLoopSound;

	muzzleVelocity      = 65;
	velInheritFactor    = 1.0;

	armingDelay         = 00;
	lifetime            = 4000;
	fadeDelay           = 3500;
	bounceElasticity    = 0.5;
	bounceFriction      = 0.20;
	isBallistic         = false;
	gravityMod = 0.0;

	hasLight    = true;
	lightRadius = 5.0;
	lightColor  = "1 0.5 0.0";

	uiName = "Roblox Rocket";
};

//////////
// item //
//////////
datablock ItemData(RobloxRocketLauncherItem)
{
	category = "Weapon";  // Mission editor category
	className = "Weapon"; // For inventory system

	 // Basic Item Properties
	shapeFile = "./robloxRL.dts";
	rotate = false;
	mass = 1;
	density = 0.2;
	elasticity = 0.2;
	friction = 0.6;
	emap = true;

	//gui stuff
	uiName = "Roblox RL";
	iconName = "";//"./icon_rocketLauncher";
	doColorShift = false;

	 // Dynamic properties defined by the scripts
	image = RobloxRocketLauncherImage;
	canDrop = true;
};

////////////////
//weapon image//
////////////////
datablock ShapeBaseImageData(RobloxRocketLauncherImage)
{
	// Basic Item properties
	shapeFile = "./robloxRL.dts";
	emap = true;

	// Specify mount point & offset for 3rd person, and eye 2offset
	// for first person rendering.
	mountPoint = 0;
	offset = "0 0 0";
	eyeOffset = 0; //"0.7 1.2 -0.5";
	rotation = eulerToMatrix( "0 0 0" );

	// When firing from a point offset from the eye, muzzle correction
	// will adjust the muzzle vector to point to the eye LOS point.
	// Since this weapon doesn't actually fire from the muzzle point,
	// we need to turn this off.  
	correctMuzzleVector = true;

	// Add the WeaponImage namespace as a parent, WeaponImage namespace
	// provides some hooks into the inventory system.
	className = "WeaponImage";

	// Projectile && Ammo.
	item = RobloxRocketLauncherItem;
	ammo = " ";
	projectile = RobloxRocketLauncherProjectile;
	projectileType = Projectile;

	//melee particles shoot from eye node for consistancy
	melee = false;
	//raise your arm up or not
	armReady = true;
	minShotTime = 700;   //minimum time allowed between shots (needed to prevent equip/dequip exploit)

	doColorShift = false;

	//casing = " ";

	// Images have a state system which controls how the animations
	// are run, which sounds are played, script callbacks, etc. This
	// state system is downloaded to the client so that clients can
	// predict state changes and animate accordingly.  The following
	// system supports basic ready->fire->reload transitions as
	// well as a no-ammo->dryfire idle state.

	// Initial start up state
	stateName[0]                     = "Activate";
	stateTimeoutValue[0]             = 0.1;
	stateTransitionOnTimeout[0]       = "Ready";
	stateSound[0]					= weaponSwitchSound;

	stateName[1]                     = "Ready";
	stateTransitionOnTriggerDown[1]  = "Fire";
	stateAllowImageChange[1]         = true;
	stateTransitionOnNoAmmo[1]       = "NoAmmo";
	stateSequence[1]	= "Ready";

	stateName[2]                    = "Fire";
	stateTransitionOnTimeout[2]     = "Smoke1";
	stateTimeoutValue[2]            = 0.1;
	stateFire[2]                    = true;
	stateAllowImageChange[2]        = false;
	stateSequence[2]                = "Fire";
	stateScript[2]                  = "onFire";
	stateWaitForTimeout[2]			= true;
	stateEmitter[2]					= rocketLauncherFlashEmitter;
	stateEmitterTime[2]				= 0.05;
	stateEmitterNode[2]				= tailNode;
	stateSound[2]					= RobloxRocketFireSound;
	//stateEjectShell[2]       = true;

	stateName[7] = "Smoke1";
	stateEmitter[7] = rocketLauncherSmokeEmitter;
	stateEmitterTime[7]				= 0.05;
	stateEmitterNode[7]				= "rearVent";
	stateTransitionOnTimeout[7]     = "Smoke";

	stateName[3] = "Smoke";
	stateEmitter[3]					= rocketLauncherSmokeEmitter;
	stateEmitterTime[3]				= 0.05;
	stateEmitterNode[3]				= "muzzleNode";
	stateTimeoutValue[3]            = 0.1;
	stateTransitionOnTimeout[3]     = "CoolDown";

	stateName[5] = "CoolDown";
	stateTimeoutValue[5]            = 0.5;
	stateTransitionOnTimeout[5]     = "Reload";


	stateName[4]			= "Reload";
	stateTransitionOnTriggerUp[4]     = "Ready";

	stateName[6]   = "NoAmmo";
	stateTransitionOnAmmo[6] = "Ready";
};

function RobloxRocketLauncherImage::onFire(%obj, %pl, %slot)
{
	Parent::onFire(%obj, %pl, %slot);

	%obj.playThread(2, plant);	
}

